// Vertex Shader  file "static_shader.vert"
// static means no modifications to the mesh

#version 330 core

uniform mat4 PVM;
uniform mat4 mvMatrix;
uniform mat4 normalMatrix;
uniform mat4 TM; // for SM: the texture matrix multiplied with model matrix

in  vec4 in_position;
in  vec2 in_textCoords;
in  vec3 in_normal;

out vec2 ex_textCoords;
out vec3 ex_normal;
out vec3 ex_ecPosition;
out vec3 ex_eyeVector;
out vec4 SM_tex_coord; // for SM: pass to fragment shader -> the coordinates for texture access


void main(void)
{
	//Get surface normal in eye coordinates
	ex_normal = (normalMatrix * vec4(in_normal,1.0) ).xyz;

	//Get vertex position in eye coordinates
	ex_ecPosition = (mvMatrix * in_position).xyz;

	//Get Vector from surface to eye
	ex_eyeVector = normalize(-ex_ecPosition);

	ex_textCoords = in_textCoords;

	// for SM: calculate the texture access coordinates
	SM_tex_coord = TM * in_position;

	gl_Position = PVM * in_position;
}